@@ -4,7 +4,7 @@
 #' alphabetical order. To override this, provide a `reference` section in your
 #' `_pkgdown.yml` as described below.
 #'
-#' @section Reference index:
+#' # Reference index
 #' To tweak the index page, add a section called `reference` to `_pkgdown.yml`.
 #' It can contain three different types of element:
 #'
@@ -80,8 +80,10 @@
 #'    captured by `has_concepts()`.
 #' * Topics from other installed packages, e.g. `rlang::is_installed()` (function name)
 #'  or `sass::font_face` (topic name).
+#' * `has_lifecycle("deprecated")` will select all topics with lifecycle
+#'   deprecated.
 #'
-#' All functions (except for `has_keywords()`) automatically exclude internal
+#' All functions (except for `has_keyword()`) automatically exclude internal
 #' topics (i.e. those with `\keyword{internal}`). You can choose to include
 #' with (e.g.) `starts_with("build_", internal = TRUE)`.
 #'
@@ -104,12 +106,12 @@
 #' either 30x30 (for regular display) or 60x60 (if you want retina display).
 #' Icons are matched to topics by aliases.
 #'
-#' ## Examples
+#' # Examples
 #'
 #' If you need to run extra code before or after all examples are run, you
 #' can create `pkgdown/pre-reference.R` and `pkgdown/post-reference.R`.
 #'
-#' @section Figures:
+#' # Figures
 #'
 #' You can control the default rendering of figures by specifying the `figures`
 #' field in `_pkgdown.yml`. The default settings are equivalent to:
@@ -134,6 +136,7 @@
 #' as HTML widgets.
 #'
 #' @inheritParams build_articles
+#' @family site components
 #' @param lazy If `TRUE`, only rebuild pages where the `.Rd`
 #'   is more recent than the `.html`. This makes it much easier to
 #'   rapidly prototype. It is set to `FALSE` by [build_site()].
@@ -143,30 +146,27 @@
 #'   If `TRUE` (the default), assumes you are in a live development
 #'   environment, and loads source package with [pkgload::load_all()].
 #'   If `FALSE`, uses the installed version of the package.
-#' @param document **Deprecated** Use `devel` instead.
 #' @param topics Build only specified topics. If supplied, sets `lazy`
 #'   and `preview` to `FALSE`.
 #' @export
-build_reference <- function(pkg = ".",
-                            lazy = TRUE,
-                            examples = TRUE,
-                            run_dont_run = FALSE,
-                            seed = 1014L,
-                            override = list(),
-                            preview = NA,
-                            devel = TRUE,
-                            document = "DEPRECATED",
-                            topics = NULL) {
-  pkg <- section_init(pkg, depth = 1L, override = override)
-
-  if (document != "DEPRECATED") {
-    lifecycle::deprecate_warn(
-      "1.4.0",
-      "build_site(document)",
-      details = "build_site(devel)"
-    )
-    devel <- document
-  }
+build_reference <- function(
+  pkg = ".",
+  lazy = TRUE,
+  examples = TRUE,
+  run_dont_run = FALSE,
+  seed = 1014L,
+  override = list(),
+  preview = FALSE,
+  devel = TRUE,
+  topics = NULL
+) {
+  pkg <- section_init(pkg, "reference", override = override)
+  check_bool(lazy)
+  check_bool(examples)
+  check_bool(run_dont_run)
+  check_number_whole(seed, allow_null = TRUE)
+  check_bool(devel)
+  check_character(topics, allow_null = TRUE)
 
   cli::cli_rule("Building function reference")
   build_reference_index(pkg)
@@ -194,26 +194,37 @@ build_reference <- function(pkg = ".",
     lazy = lazy,
     examples_env = examples_env,
     run_dont_run = run_dont_run
-  )) 
+  ))
 
   preview_site(pkg, "reference", preview = preview)
 }
 
 copy_figures <- function(pkg) {
   # copy everything from man/figures to docs/reference/figures
-  src_figures <- path(pkg$src_path, "man", "figures")
-  dst_figures <- path(pkg$dst_path, "reference", "figures")
-  if (file_exists(src_figures)) {
-    dir_copy_to(pkg, src_figures, dst_figures)
-  }
+  dir_copy_to(
+    src_dir = path(pkg$src_path, "man", "figures"),
+    src_root = pkg$src_path,
+    dst_dir = path(pkg$dst_path, "reference", "figures"),
+    dst_root = pkg$dst_path
+  )
 }
 
-examples_env <- function(pkg, seed = 1014L, devel = TRUE, envir = parent.frame()) {
+examples_env <- function(
+  pkg,
+  seed = 1014L,
+  devel = TRUE,
+  envir = parent.frame()
+) {
   # Re-loading pkgdown while it's running causes weird behaviour with
   # the context cache
   if (isTRUE(devel) && !(pkg$package %in% c("pkgdown", "rprojroot"))) {
     check_installed("pkgload", "to use `build_reference(devel = TRUE)`")
-    pkgload::load_all(pkg$src_path, export_all = FALSE, helpers = FALSE, quiet = TRUE)
+    pkgload::load_all(
+      pkg$src_path,
+      export_all = FALSE,
+      helpers = FALSE,
+      quiet = TRUE
+    )
   } else {
     library(pkg$package, character.only = TRUE)
   }
@@ -223,7 +234,7 @@ examples_env <- function(pkg, seed = 1014L, devel = TRUE, envir = parent.frame()
   post_path <- path_abs(path(pkg$src_path, "pkgdown", "post-reference.R"))
 
   withr::local_dir(path(pkg$dst_path, "reference"), .local_envir = envir)
-  width <- purrr::pluck(pkg, "meta", "code", "width", .default = 80)
+  width <- config_pluck_number_whole(pkg, "code.width", default = 80)
   withr::local_options(width = width, .local_envir = envir)
   withr::local_seed(seed, .local_envir = envir)
   if (requireNamespace("htmlwidgets", quietly = TRUE)) {
@@ -243,19 +254,20 @@ examples_env <- function(pkg, seed = 1014L, devel = TRUE, envir = parent.frame()
 
 #' @export
 #' @rdname build_reference
-build_reference_index <- function(pkg = ".") {
-  pkg <- section_init(pkg, depth = 1L)
-  create_subdir(pkg, "reference")
+build_reference_index <- function(pkg = ".", override = list()) {
+  pkg <- section_init(pkg, "reference", override = override)
 
   # Copy icons, if needed
-  src_icons <- path(pkg$src_path, "icons")
-  dst_icons <- path(pkg$dst_path, "reference", "icons")
-  if (file_exists(src_icons)) {
-    dir_copy_to(pkg, src_icons, dst_icons)
-  }
+  dir_copy_to(
+    src_dir = path(pkg$src_path, "icons"),
+    src_root = pkg$src_path,
+    dst_dir = path(pkg$dst_path, "reference", "icons"),
+    dst_root = pkg$dst_path
+  )
 
   render_page(
-    pkg, "reference-index",
+    pkg,
+    "reference-index",
     data = data_reference_index(pkg),
     path = "reference/index.html"
   )
@@ -264,17 +276,17 @@ build_reference_index <- function(pkg = ".") {
 }
 
 
-build_reference_topic <- function(topic,
-                                  pkg,
-                                  lazy = TRUE,
-                                  examples_env = globalenv(),
-                                  run_dont_run = FALSE) {
-
+build_reference_topic <- function(
+  topic,
+  pkg,
+  lazy = TRUE,
+  examples_env = globalenv(),
+  run_dont_run = FALSE
+) {
   in_path <- path(pkg$src_path, "man", topic$file_in)
   out_path <- path(pkg$dst_path, "reference", topic$file_out)
 
-  if (lazy && !out_of_date(in_path, out_path))
-    return(invisible())
+  if (lazy && !out_of_date(in_path, out_path)) return(invisible())
 
   cli::cli_inform("Reading {src_path(path('man', topic$file_in))}")
 
@@ -287,7 +299,7 @@ build_reference_topic <- function(topic,
     ),
     error = function(err) {
       cli::cli_abort(
-        "Failed to parse Rd in {.file {topic$file_in}}", 
+        "Failed to parse Rd in {.file {topic$file_in}}",
         parent = err,
         call = quote(build_reference())
       )
@@ -302,20 +314,21 @@ build_reference_topic <- function(topic,
     deps <- purrr::map(
       deps,
       htmltools::copyDependencyToDir,
-      outputDir = file.path(pkg$dst_path, "reference", "libs"),
+      outputDir = path(pkg$dst_path, "reference", "libs"),
       mustWork = FALSE
     )
     deps <- purrr::map(
       deps,
       htmltools::makeDependencyRelative,
-      basepath = file.path(pkg$dst_path, "reference"),
+      basepath = path(pkg$dst_path, "reference"),
       mustWork = FALSE
     )
     data$dependencies <- htmltools::renderDependencies(deps, c("file", "href"))
   }
 
   render_page(
-    pkg, "reference-topic",
+    pkg,
+    "reference-topic",
     data = data,
     path = path("reference", topic$file_out)
   )
@@ -326,11 +339,12 @@ build_reference_topic <- function(topic,
 
 # Convert Rd to list ------------------------------------------------------
 
-data_reference_topic <- function(topic,
-                                 pkg,
-                                 examples_env = globalenv(),
-                                 run_dont_run = FALSE) {
-
+data_reference_topic <- function(
+  topic,
+  pkg,
+  examples_env = globalenv(),
+  run_dont_run = FALSE
+) {
   local_context_eval(pkg$figures, pkg$src_path)
   withr::local_options(list(downlit.rdname = get_rdname(topic)))
 
@@ -363,7 +377,6 @@ data_reference_topic <- function(topic,
     )
   }
 
-
   if (!is.null(tags$tag_examples)) {
     out$examples <- run_examples(
       tags$tag_examples[[1]],
@@ -379,23 +392,30 @@ data_reference_topic <- function(topic,
   }
 
   # Everything else stays in original order, and becomes a list of sections.
-  section_tags <- paste0("tag_", c(
-    "arguments", "value", "details", "references", "source", "format", "note",
-    "seealso", "section", "author"
-  ))
+  section_tags <- paste0(
+    "tag_",
+    c(
+      "arguments",
+      "value",
+      "details",
+      "references",
+      "source",
+      "format",
+      "note",
+      "seealso",
+      "section",
+      "author"
+    )
+  )
   sections <- topic$rd[tag_names %in% section_tags]
-  out$sections <- sections %>%
-    purrr::map(as_data) %>%
-    purrr::map(add_slug)
-
+  out$sections <- purrr::map(sections, function(section) {
+    data <- as_data(section)
+    data$slug <- make_slug(data$title)
+    data
+  })
   out
 }
 
-add_slug <- function(x) {
-  x$slug <- make_slug(x$title)
-  x
-}
-
 make_slug <- function(x) {
   x <- strip_html_tags(x)
   x <- tolower(x)
