@@ -18,8 +18,12 @@ flatten_para <- function(x, ...) {
 
   # Or tags that are converted to HTML blocks
   block_tags <- c(
-    "tag_preformatted", "tag_itemize", "tag_enumerate", "tag_tabular",
-    "tag_describe", "tag_subsection"
+    "tag_preformatted",
+    "tag_itemize",
+    "tag_enumerate",
+    "tag_tabular",
+    "tag_describe",
+    "tag_subsection"
   )
   is_block <- purrr::map_lgl(x, inherits, block_tags)
 
@@ -34,10 +38,9 @@ flatten_para <- function(x, ...) {
   needs_split <- !is_block & !empty
   html[needs_split] <- purrr::map(html[needs_split], split_at_linebreaks)
 
-  blocks <- html %>%
-    split(groups) %>%
-    purrr::map(unlist) %>%
-    purrr::map_chr(paste, collapse = "")
+  blocks <- purrr::map_chr(split(html, groups), function(x) {
+    paste(unlist(x), collapse = "")
+  })
 
   # There are three types of blocks:
   # 1. Combined text and inline tags
@@ -45,15 +48,19 @@ flatten_para <- function(x, ...) {
   # 3. Block-level tags
   #
   # Need to wrap 1 in <p>
-  needs_p <- (!(is_nl | is_block)) %>%
-    split(groups) %>%
-    purrr::map_lgl(any)
-
+  needs_p <- purrr::map_lgl(split(!(is_nl | is_block), groups), any)
   blocks[needs_p] <- paste0("<p>", str_trim(blocks[needs_p]), "</p>")
 
   paste0(blocks, collapse = "")
 }
 
+split_at_linebreaks <- function(text) {
+  if (length(text) == 0) {
+    character()
+  } else {
+    strsplit(text, "\\n\\s*\\n")[[1]]
+  }
+}
 
 flatten_text <- function(x, ...) {
   if (length(x) == 0) return("")
@@ -66,7 +73,7 @@ flatten_text <- function(x, ...) {
 as_html.Rd <- function(x, ...) flatten_text(x, ...)
 
 #' @export
-as_html.LIST <-  flatten_text
+as_html.LIST <- flatten_text
 
 # Leaves  -----------------------------------------------------------------
 
@@ -81,28 +88,37 @@ as_html.character <- function(x, ..., escape = TRUE) {
   }
 }
 #' @export
-as_html.TEXT <-  as_html.character
+as_html.TEXT <- function(x, ..., escape = TRUE) {
+  # tools:::htmlify
+  x <- gsub("---", "\u2014", x)
+  x <- gsub("--", "\u2013", x)
+  x <- gsub("``", "\u201c", x)
+  x <- gsub("''", "\u201d", x)
+
+  x <- as_html.character(x, ..., escape = escape)
+  x
+}
 #' @export
 as_html.RCODE <- as_html.character
 #' @export
-as_html.VERB <-  as_html.character
+as_html.VERB <- as_html.character
 #' @export
 as_html.COMMENT <- function(x, ...) {
   paste0("<!-- ", flatten_text(x), " -->")
 }
 # USERMACRO appears first, followed by the rendered macro
 #' @export
-as_html.USERMACRO <-  function(x, ...) ""
+as_html.USERMACRO <- function(x, ...) ""
 
 #' @export
 as_html.tag_subsection <- function(x, ..., subsection_level = 3L) {
-
   h <- paste0("h", subsection_level)
 
   title <- flatten_text(x[[1]], ...)
   id <- make_slug(title)
   text <- flatten_para(x[[2]], ..., subsection_level = subsection_level + 1L)
 
+  # fmt: skip
   paste0(
     "<div class='section' id='", id, "'>\n",
     "<", h, ">", title, "</", h, ">\n",
@@ -192,24 +208,6 @@ as_html.tag_linkS4class <- function(x, ...) {
   a(text, href = href)
 }
 
-# Miscellaneous --------------------------------------------------------------
-
-#' @export
-as_html.tag_method <- function(x, ...) method_usage(x, "S3")
-#' @export
-as_html.tag_S3method <- function(x, ...) method_usage(x, "S3")
-#' @export
-as_html.tag_S4method <- function(x, ...) method_usage(x, "S4")
-
-method_usage <- function(x, type) {
-  fun <- as_html(x[[1]])
-  class <- as_html(x[[2]])
-  paste0(
-    sprintf(tr_("# %s method for %s"), type, class),
-    "\n", fun
-  )
-}
-
 # Conditionals and Sexprs ----------------------------------------------------
 
 #' @export
@@ -222,18 +220,33 @@ as_html.tag_Sexpr <- function(x, ...) {
   on.exit(setwd(old_wd), add = TRUE)
 
   # Environment shared across a file
-  res <- eval(parse(text = code), context_get("sexpr_env"))
+  env <- context_get("sexpr_env")
 
   results <- options$results %||% "rd"
-  switch(results,
-    text = as.character(res),
-    rd = flatten_text(rd_text(as.character(res))),
-    hide = "",
-    cli::cli_abort(
-      "\\\\Sexpr{{result={results}}} not yet supported",
-      call = NULL
+  if (results == "verbatim") {
+    outlines <- utils::capture.output({
+      out <- withVisible(eval(parse(text = code), env))
+      res <- out$value
+      if (out$visible) print(res)
+    })
+    paste0(
+      "<pre>\n",
+      paste0(escape_html(outlines), collapse = "\n"),
+      "\n</pre>\n"
     )
-  )
+  } else {
+    res <- eval(parse(text = code), env)
+    switch(
+      results,
+      text = as.character(res),
+      rd = flatten_text(rd_text(as.character(res))),
+      hide = "",
+      cli::cli_abort(
+        "unknown \\Sexpr option: results={results}",
+        call = NULL
+      )
+    )
+  }
 }
 
 #' @export
@@ -310,14 +323,18 @@ as_html.tag_tabular <- function(x, ...) {
   cell_grp <- rev(cumsum(-rev(sep)))
   cells <- unname(split(contents, cell_grp))
   # Remove trailing content (that does not match the dimensions of the table)
-  cells <- cells[seq_len(length(cells) - length(cells)%%length(align))]
+  cells <- cells[seq_len(length(cells) - length(cells) %% length(align))]
   cell_contents <- purrr::map_chr(cells, flatten_text, ...)
   cell_contents <- paste0("<td>", str_trim(cell_contents), "</td>")
   cell_contents <- matrix(cell_contents, ncol = length(align), byrow = TRUE)
 
   rows <- apply(cell_contents, 1, paste0, collapse = "")
 
-  paste0("<table class='table'>\n", paste0("<tr>", rows, "</tr>\n", collapse = ""), "</table>\n")
+  paste0(
+    "<table class='table'>\n",
+    paste0("<tr>", rows, "</tr>\n", collapse = ""),
+    "</table>\n"
+  )
 }
 
 
@@ -334,7 +351,7 @@ as_html.tag_figure <- function(x, ...) {
     opt <- paste(trimws(as.character(x[[2]])), collapse = " ")
     if (substr(opt, 1, 9) == "options: ") {
       extra <- substr(opt, 9, nchar(opt))
-      paste0("<img src='figures/", path, "'",  extra, " />")
+      paste0("<img src='figures/", path, "'", extra, " />")
     } else {
       paste0("<img src='figures/", path, "' alt='", opt, "' />")
     }
@@ -378,31 +395,44 @@ parse_items <- function(rd, ...) {
     paste0("<li>", flatten_para(x, ...), "</li>\n")
   }
 
-  rd %>%
-    split(group) %>%
-    purrr::map_chr(parse_item) %>%
-    paste(collapse = "")
+  paste(purrr::map_chr(split(rd, group), parse_item), collapse = "")
 }
 
-parse_descriptions <- function(rd, ...) {
+parse_descriptions <- function(rd, ..., id_prefix = NULL) {
   if (length(rd) == 0) {
     return(character())
   }
 
   parse_item <- function(x) {
     if (inherits(x, "tag_item")) {
+      term <- flatten_text(x[[1]], ...)
+      def <- flatten_para(x[[2]], ...)
+
+      if (!is.null(id_prefix)) {
+        id <- paste0(id_prefix, make_slug(term))
+        id_attr <- paste0(" id='", id, "'")
+        anchor <- anchor_html(id)
+      } else {
+        id_attr <- ""
+        anchor <- ""
+      }
       paste0(
-        "<dt>", flatten_text(x[[1]], ...), "</dt>\n",
-        "<dd>", flatten_para(x[[2]], ...), "</dd>\n"
+        "<dt",
+        id_attr,
+        ">",
+        term,
+        anchor,
+        "</dt>\n",
+        "<dd>",
+        def,
+        "</dd>\n"
       )
     } else {
       flatten_text(x, ...)
     }
   }
 
-  rd %>%
-    purrr::map_chr(parse_item) %>%
-    paste(collapse = "")
+  paste(purrr::map_chr(rd, parse_item), collapse = "")
 }
 
 # Marking text ------------------------------------------------------------
@@ -416,19 +446,19 @@ tag_wrapper <- function(prefix, suffix = NULL) {
 }
 
 #' @export
-as_html.tag_emph <-         tag_wrapper("<em>", "</em>")
+as_html.tag_emph <- tag_wrapper("<em>", "</em>")
 #' @export
-as_html.tag_strong <-       tag_wrapper("<strong>", "</strong>")
+as_html.tag_strong <- tag_wrapper("<strong>", "</strong>")
 #' @export
-as_html.tag_bold <-         tag_wrapper("<b>", "</b>")
+as_html.tag_bold <- tag_wrapper("<b>", "</b>")
 
 #' @export
-as_html.tag_dQuote <-       tag_wrapper("&#8220;", "&#8221;")
+as_html.tag_dQuote <- tag_wrapper("&#8220;", "&#8221;")
 #' @export
-as_html.tag_sQuote <-       tag_wrapper("&#8216;", "&#8217;")
+as_html.tag_sQuote <- tag_wrapper("&#8216;", "&#8217;")
 
 #' @export
-as_html.tag_code <-         function(x, ..., auto_link = TRUE) {
+as_html.tag_code <- function(x, ..., auto_link = TRUE) {
   text <- flatten_text(x, ...)
 
   if (auto_link) {
@@ -446,32 +476,32 @@ as_html.tag_preformatted <- function(x, ...) {
 }
 
 #' @export
-as_html.tag_kbd <-          tag_wrapper("<kbd>", "</kbd>")
+as_html.tag_kbd <- tag_wrapper("<kbd>", "</kbd>")
 #' @export
-as_html.tag_samp <-         tag_wrapper('<samp>',"</samp>")
+as_html.tag_samp <- tag_wrapper('<samp>', "</samp>")
 #' @export
-as_html.tag_verb <-         tag_wrapper("<code>", "</code>")
+as_html.tag_verb <- tag_wrapper("<code>", "</code>")
 
 #' @export
-as_html.tag_pkg <-          tag_wrapper('<span class="pkg">',"</span>")
+as_html.tag_pkg <- tag_wrapper('<span class="pkg">', "</span>")
 #' @export
-as_html.tag_file <-         tag_wrapper('<code class="file">', '</code>')
+as_html.tag_file <- tag_wrapper('<code class="file">', '</code>')
 
 #' @export
-as_html.tag_var <-          tag_wrapper("<var>", "</var>")
+as_html.tag_var <- tag_wrapper("<var>", "</var>")
 #' @export
-as_html.tag_env <-          tag_wrapper('<code class="env">', '</code>')
+as_html.tag_env <- tag_wrapper('<code class="env">', '</code>')
 #' @export
-as_html.tag_option <-       tag_wrapper('<span class="option">',"</span>")
+as_html.tag_option <- tag_wrapper('<span class="option">', "</span>")
 #' @export
-as_html.tag_command <-      tag_wrapper("<code class='command'>", "</code>")
+as_html.tag_command <- tag_wrapper("<code class='command'>", "</code>")
 
 #' @export
-as_html.tag_dfn <-          tag_wrapper("<dfn>", "</dfn>")
+as_html.tag_dfn <- tag_wrapper("<dfn>", "</dfn>")
 #' @export
-as_html.tag_cite <-         tag_wrapper("<cite>", "</cite>")
+as_html.tag_cite <- tag_wrapper("<cite>", "</cite>")
 #' @export
-as_html.tag_acronym <-      tag_wrapper('<acronym>','</acronym>')
+as_html.tag_acronym <- tag_wrapper('<acronym>', '</acronym>')
 
 #' @export
 as_html.tag_out <- function(x, ...) flatten_text(x, ..., escape = FALSE)
@@ -479,13 +509,13 @@ as_html.tag_out <- function(x, ...) flatten_text(x, ..., escape = FALSE)
 # Insertions --------------------------------------------------------------
 
 #' @export
-as_html.tag_R <-     function(x, ...) '<span style="R">R</span>'
+as_html.tag_R <- function(x, ...) '<span style="R">R</span>'
 #' @export
-as_html.tag_dots <-  function(x, ...) "..."
+as_html.tag_dots <- function(x, ...) "..."
 #' @export
 as_html.tag_ldots <- function(x, ...) "..."
 #' @export
-as_html.tag_cr <-    function(x, ...) "<br>"
+as_html.tag_cr <- function(x, ...) "<br>"
 
 # First element of enc is the encoded version (second is the ascii version)
 #' @export
@@ -500,7 +530,7 @@ as_html.tag_enc <- function(x, ...) {
 # Elements that don't return anything ----------------------------------------
 
 #' @export
-as_html.tag_tab <-      function(x, ...) ""
+as_html.tag_tab <- function(x, ...) ""
 #' @export
 as_html.tag_newcommand <- function(x, ...) ""
 #' @export
@@ -521,10 +551,8 @@ as_html.tag <- function(x, ...) {
 trim_ws_nodes <- function(x, side = c("both", "left", "right")) {
   is_ws <- purrr::map_lgl(x, ~ inherits(., "TEXT") && grepl("^\\s*$", .[[1]]))
 
-  if (!any(is_ws))
-    return(x)
-  if (all(is_ws))
-    return(x[0])
+  if (!any(is_ws)) return(x)
+  if (all(is_ws)) return(x[0])
 
   which_not <- which(!is_ws)
 
@@ -556,7 +584,6 @@ parse_opts <- function(string) {
   names(args) <- args
   arg_env <- child_env(baseenv(), !!!args)
 
-
   args <- strsplit(string, ",")[[1]]
   exprs <- purrr::map(args, parse_expr)
 
