@@ -15,13 +15,14 @@ ext_topics <- function(match_strings) {
     file_in = NA_character_,
     file_out = ext_href,
     alias = list(character()), # used to find icons,
-    funs = ext_funs,           # used list alternative names
+    funs = ext_funs, # used list alternative names
     title = sprintf("%s (from %s)", ext_title, pkg),
     rd = list(character()),
     source = NA_character_,
     keywords = list(character()), # used for has_keyword()
     concepts = list(character()), # used for has_concept()
-    internal = FALSE
+    internal = FALSE,
+    lifecycle = list(NULL) # used for has_lifecycle
   )
 }
 
