@@ -1,22 +1,29 @@
 #' A
 #' @export
 #' @keywords foo
-a <- function() {}
+#' @param a a letter
+#' @param b a a number
+#' @param c a logical
+a <- function(a, b, c) {
+}
 
 #' B
 #' @export
 #' @concept graphics
-b <- function() {}
+b <- function() {
+}
 
 #' C
 #' @export
-c <- function() {}
+c <- function() {
+}
 
 #' D
 #' @usage
 #' \special{?topic}
 #' @export
-`?` <- function() {}
+`?` <- function() {
+}
 
 #' E
 #' @name e
@@ -26,4 +33,11 @@ NULL
 #' @keywords internal
 #' @examples
 #' testpackage:::f()
-f <- function() {runif(5L)}
+f <- function() {
+  runif(5L)
+}
+
+
+#' g <-> h
+#' @keywords internal
+g <- function() 1
