@@ -1,5 +1,5 @@
 test_that("highlight_examples captures dependencies", {
-  withr::defer(unlink(test_path("Rplot001.png")))
+  withr::defer(try(file_delete(test_path("Rplot001.png")), TRUE))
 
   dummy_dep <- htmltools::htmlDependency("dummy", "1.0.0", "dummy.js")
   widget <- htmlwidgets::createWidget("test", list(), dependencies = dummy_dep)
@@ -9,8 +9,13 @@ test_that("highlight_examples captures dependencies", {
   expect_equal(attr(out, "dependencies")[-1], list(dummy_dep))
 })
 
+test_that("highlight_examples runs and hides DONTSHOW calls()", {
+  out <- highlight_examples("DONTSHOW(x <- 1)\nx")
+  expect_snapshot(cat(strip_html_tags(out)))
+})
+
 test_that("highlight_text & highlight_examples include sourceCode div", {
-  withr::defer(unlink(test_path("Rplot001.png")))
+  withr::defer(try(file_delete(test_path("Rplot001.png")), TRUE))
 
   html <- xml2::read_html(highlight_examples("a + a", "x"))
   expect_equal(xpath_attr(html, "./body/div", "class"), "sourceCode")
@@ -27,29 +32,30 @@ test_that("pre() can produce needed range of outputs", {
 })
 
 test_that("tweak_highlight_other() renders generic code blocks for roxygen2 >= 7.2.0", {
-  div <- xml2::read_html('<div class="sourceCode"><pre><code>1+1\n</code></pre></div>') %>%
-    xml2::xml_find_first("//div")
-  tweak_highlight_other(div)
-  expect_equal(
-    xml2::xml_text(xml2::xml_find_first(div, "pre/code")),
-    "1+1"
+  html <- xml2::read_html(
+    '<div class="sourceCode"><pre><code>1+1\n</code></pre></div>'
   )
+  div <- xml2::xml_find_first(html, "//div")
+
+  tweak_highlight_other(div)
+  expect_equal(xpath_text(div, "pre/code"), "1+1")
 })
 
 test_that("tweak_highlight_other() renders nested code blocks for roxygen2 >= 7.2.0", {
-  div <- xml2::read_html(
-"<div class='sourceCode markdown'><pre><code>
-blablabla
+  html <- xml2::read_html(dedent(
+    "
+    <div class='sourceCode markdown'><pre><code>
+    blablabla
 
-```{r results='asis'}
-lalala
-```
+    ```{r results='asis'}
+    lalala
+    ```
+
+    </code></pre></div>
+  "
+  ))
+  div <- xml2::xml_find_first(html, "//div")
 
-</code></pre></div>") %>%
-    xml2::xml_find_first("//div")
   tweak_highlight_other(div)
-  expect_match(
-    xml2::xml_text(xml2::xml_find_first(div, "pre/code")),
-    "```.?\\n"
-  )
+  expect_snapshot(cat(xpath_text(div, "pre/code")))
 })
